<?php

// Authentification

if (@file_exists('inc/auth.inc.php') && @include_once 'inc/auth.inc.php');
else exit;

// General options

$ezin_opts['dbh'] = ezin_open_db_connection();
$ezin_opts['tb']  = $ezin_sys['db']['tables']['articles'];
$ezin_opts['key'] = 'id';
$ezin_opts['key_type'] = 'int';
$ezin_opts['inc'] = 15;
$ezin_opts['options'] = $ezin_USER['role_articles'];
$ezin_opts['multiple'] = '4';
$ezin_opts['navigation'] = $ezin_cfg['admin_navigation'].$ezin_cfg['admin_buttons_pos'];
$ezin_opts['display'] = array('query' => false, 'sort'  => false, 'time'  => false);
$ezin_opts['url'] = array('images' => 'icons/');
$ezin_opts['sort_field'] = array($ezin_admin_action=='pages'?'access_key':'-datetime', '-id');
$ezin_opts['language'] = 'EN';

// Buttons

$ezin_opts['buttons']['C']['up'] = array('save','more','cancel', '&nbsp;&nbsp;&nbsp;',
	array('name' => 'wordclean', 'value' => 'Word Clean', 'css' => 'pme-wordclean', 'disabled' => false),
	array('name' => 'switch', 'value' => 'Move to '.($ezin_admin_action=='pages'?'Articles':'Pages'),
			'css' => 'pme-switch', 'disabled' => false));
$ezin_opts['buttons']['C']['down'] = $ezin_opts['buttons']['C']['up'];

// Triggers

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/word-count.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/word-count.trigger';

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/text-flags.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/text-flags.trigger';

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/access-key.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/access-key.trigger';

$ezin_opts['triggers']['insert']['after'][] = 'inc-db/triggers/articles.after';
$ezin_opts['triggers']['update']['after'][] = 'inc-db/triggers/articles.after';
$ezin_opts['triggers']['delete']['after'][] = 'inc-db/triggers/articles.after';

// Filters

if ($ezin_admin_action == 'pages') {
	$ezin_opts['filters'] = 'UNIX_TIMESTAMP(datetime) = 0';
} else {
	$ezin_opts['filters'] = 'UNIX_TIMESTAMP(datetime) != 0';
}

// Field definitions

$ezin_opts['fdd']['id'] = array(
		'name'=>($ezin_admin_action=='pages'?'Page ID':'Article ID'),
		'name|LF'=>'ID',
		'select'=>'T',
		'sort'=>true,
		'size'=>5,
		'default'=>'',
		'options'=>'LDVFPCR',
		'URL'=>ezin_get_link('A', '$value'),
		// TODO: fix for length >= 5
		'sql|LF'=>'IF(TRIM(PMEtable0.access_key) != "",'
			.' CONCAT(LPAD(PMEtable0.id,4,"0"), "<!--", PMEtable0.access_key, "-->"), LPAD(PMEtable0.id,4,"0"))',
		'escape' => false
		);

$ezin_opts['fdd']['status'] = array(
		'name'=>'Status',
		'name|LF'=>'S',
		'select'=>'D',
		'values'=>array(),
		'values2'=> array(
			'showed'        => '<b>showed</b> (default)',
			'partly_showed' => '<b>partly showed</b> (hidden from global sections)',
			'hidden'        => '<b>not showed</b> (hidden, but accessible)',
			'disabled'      => '<b>disabled</b> (unaccessible)'),
		'values2|LF'=>array(
			''              => '<code>S?</code>',
			'showed'        => '<code>S</code>',
			'partly_showed' => '<code>s</code>',
			'hidden'        => '<code>H</code>',
			'disabled'      => '<code>D</code>'),
		'sort'=>true
		);

$template_keys = ezin_admin_get_template_keys($ezin_sys['tmpl']['articles']);
if (count($template_keys) > 0) {
	$ezin_opts['fdd']['template_key'] = array(
			'name'=>Platon::htmlspecialchars2('Template key'),
			'name|LF'=>'Key',
			'sort'=>true,
			'select'=>'T',
			'options'=>'ACPDV',
			'values2'=> array(''=>' - default template - '),
			'values' => $template_keys
			);
}

$ezin_opts['fdd']['access_key'] = array(
		'name'=>Platon::htmlspecialchars2('Access key'),
		'name|LF'=>'Key',
		'sort'=>true,
		'select'=>'T',
		'options'=>'ACPDV'.($ezin_admin_action == 'pages' ? 'LF' : '')

		);

$ezin_opts['fdd']['datetime'] = array(
		'name'=>Platon::htmlspecialchars2('Date & Time'),
		'select'=>'T',
		'sort'=>true,
		'required'=>true,
		'mask'=>'%.10s',
		'options'=>($ezin_admin_action == 'pages' ? 'ACPVDRH' : 'ACPVDLF'),
		'default'=>($ezin_admin_action == 'pages' ? '0000-00-00' : date('Y-m-d H:i:s'))
		);


$ezin_opts['fdd']['bind_lang'] = array(
		'name'=>Platon::htmlspecialchars2('Language bind'),
		'select'=>'D',
		'sort'=>true,
		'options' => 0 && is_array($ezin_cfg['languages']) ? 'ACPVD' : ''
		);

$ezin_opts['fdd']['bind_theme'] = array(
		'name'=>Platon::htmlspecialchars2('Theme bind'),
		'select'=>'D',
		'sort'=>true,
		'options' => 0 && 1 ? 'ACPVD' : ''
		);

$ezin_opts['fdd']['accesses_count'] = array(
		'name'=>Platon::htmlspecialchars2('Accesses count'),
		'options'=>'VDACP'.'HR',
		'default'=>'0'
		);

$ezin_opts['fdd']['sessions_count'] = array(
		'name'=>Platon::htmlspecialchars2('Sessions count'),
		'options'=>'VDACP'.'HR',
		'default'=>'0'
		);

$ezin_opts['fdd']['message_count'] = array(
		'name'=>Platon::htmlspecialchars2('Message count'),
		'options'=>'VDACP'.'HR',
		'default'=>'0'
		);


$ezin_opts['fdd']['author_id'] = array(
		'name'=>'Author',
		'select'=>'D',
		'sort'=>true,
		'required'=>true,
		'values'=>array(
			'table' => $ezin_sys['db']['tables']['authors'],
			'column' => 'id',
			'description' => 'name')
		);

if ($ezin_cfg['single_author_id'] >= 0) {
	/* If we have just one Author in DB, we do not need to show him */
	$ezin_opts['fdd']['author_id']['options'] = 'ACPVDRH';
	$ezin_opts['fdd']['author_id']['default'] = $ezin_cfg['single_author_id'];
}

$ezin_opts['fdd']['section_id'] = array(
		'name'=>'Section',
		'select'=>'D',
		'sort'=>true,
		'required'=>true,
		'values'=>array(
			'table' => $ezin_sys['db']['tables']['sections'],
			'orderby' => 'lang,ord,id',
			'column' => 'id',
			'description' => array(
				'columns' => array('name', 'id', 'lang'),
				'divs'    => array(' (', ') ',''))),
		);

if ($ezin_admin_action != 'pages') {
	$ezin_opts['fdd']['atitle'] = array(
			'name'=>Platon::htmlspecialchars2('Annotation title'),
			'select'=>'T',
			'maxlen'=>255,
			'sort'=>true,
			'options'=>'ACPVD',
			);
}

$ezin_opts['fdd']['title'] = array(
		'name'=>'Title',
		'select'=>'T',
		'maxlen'=>255,
		'sort'=>true,
		'trimlen|LF'=>35,
		'sql|LF'=>'IF(TRIM(title) != "", title, atitle)'
		);

$ezin_opts['fdd']['hometext_wordcount'] = array(
		'name'=>Platon::htmlspecialchars2('Anotation word count'),
		'select'=>'T',
		'options'=>'HCAP'
		);

$ezin_opts['fdd']['bodytext_wordcount'] = array(
		'name'=>Platon::htmlspecialchars2('Text word count'),
		'select'=>'T',
		'options'=>'HCAP'
		);

$ezin_opts['fdd']['hometext_flags'] = array(
		'name'=>Platon::htmlspecialchars2('Anotation flags'),
		'select'=>'T',
		'options'=>'HCAP'
		);

$ezin_opts['fdd']['bodytext_flags'] = array(
		'name'=>Platon::htmlspecialchars2('Text flags'),
		'select'=>'T',
		'options'=>'HCAP'
		);

if ($ezin_admin_action != 'pages') {
	$ezin_opts['fdd']['hometext'] = array(
			'name'=>'Anotation',
			'select'=>'T',
			'textarea'=>array(
				'rows'=>8,
				'cols'=>65,
				),
			'options'=>'ACPV'
			);
}

$ezin_opts['fdd']['bodytext'] = array(
		'name'=>Platon::htmlspecialchars2('Article text'),
		'select'=>'T',
		'textarea'=>array(
			'rows'=>15,
			'cols'=>65,
			'wrap'=>'virtual'
			),
		'options'=>'ACPV'
		);

// Execution code

if (! ezin_admin_check_list_privileges($ezin_opts['options'])) {
	require 'inc-html/permdenied.html';
} else {
	/* if (! ezin_admin_check_privileges($ezin_opts['options'],
	   isset($author_id) && $author_id == $ezin_USER['author_id'])) {
	   require 'inc-html/permdenied.html';
	   } */

	require_once 'phpMyEdit/phpMyEdit.class.php';
	$ezin_opts['execute'] = 0;
	$phpMyEdit = new phpMyEdit($ezin_opts);
	if ($phpMyEdit->get_sys_cgi_var('wordclean')) {
		$content = $phpMyEdit->get_data_cgi_var('bodytext');
		$content = ezin_admin_word_clean($content);
		$phpMyEdit->myQuery(sprintf('UPDATE %s SET bodytext = "%s" WHERE id = %d',
			$ezin_opts['tb'], addslashes($content), $phpMyEdit->rec));
	} elseif ($phpMyEdit->get_sys_cgi_var('switch')) {
		$datetime = $phpMyEdit->get_data_cgi_var('datetime');
		if (strncmp($datetime, '0000-00-00', 10)) {
			$phpMyEdit->myQuery(sprintf('UPDATE %s SET datetime = "0000-00-00"
						WHERE id = %d AND UNIX_TIMESTAMP(datetime) != 0',
						$ezin_opts['tb'], $phpMyEdit->rec));
		} else {
			$phpMyEdit->myQuery(sprintf('UPDATE %s SET datetime = SYSDATE()
						WHERE id = %d AND UNIX_TIMESTAMP(datetime) = 0',
						$ezin_opts['tb'], $phpMyEdit->rec));
		}
	}

	$phpMyEdit->execute();
}

?>
