<?php

// Authentification

if (@file_exists('inc/auth.inc.php') && @include_once 'inc/auth.inc.php');
else exit;

// General options

$ezin_opts['dbh'] = ezin_open_db_connection();
$ezin_opts['tb']  = $ezin_sys['db']['tables']['authors'];
$ezin_opts['key'] = 'id';
$ezin_opts['key_type'] = 'int';
$ezin_opts['inc'] = 20;
$ezin_opts['options'] = $ezin_USER['role_authors'];
$ezin_opts['multiple'] = '4';
$ezin_opts['navigation'] = $ezin_cfg['admin_navigation'].$ezin_cfg['admin_buttons_pos'];
$ezin_opts['display'] = array('query' => false, 'sort'  => false, 'time'  => false);
$ezin_opts['url'] = array('images' => 'icons/');
$ezin_opts['sort_field'] = '-id';
$ezin_opts['language'] = 'EN';

// Triggers

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/authors.before';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/authors.before';
$ezin_opts['triggers']['delete']['before'][] = 'inc-db/triggers/authors.before';

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/word-count.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/word-count.trigger';

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/text-flags.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/text-flags.trigger';

$ezin_opts['triggers']['insert']['before'][] = 'inc-db/triggers/access-key.trigger';
$ezin_opts['triggers']['update']['before'][] = 'inc-db/triggers/access-key.trigger';

$ezin_opts['triggers']['insert']['after'][] = 'inc-db/triggers/single-author-id.trigger';
$ezin_opts['triggers']['delete']['after'][] = 'inc-db/triggers/single-author-id.trigger';

$ezin_opts['triggers']['update']['after'][] = 'inc-db/triggers/authors.after';
$ezin_opts['triggers']['delete']['after'][] = 'inc-db/triggers/authors.after';

// Field definitions

$ezin_opts['fdd']['id'] = array(
		'name'=>'ID',
		'select'=>'T',
		'sort'=>true,
		'size'=>5,
		'default'=>'',
		'options'=>'LDVFPCR',
		'URL'=>ezin_get_link('U', '$value'),
		// TODO: fix for length >= 4
		'sql|LF'=>'IF(TRIM(PMEtable0.access_key) != "",'
			.' CONCAT(LPAD(PMEtable0.id,3,"0"), "<!--", PMEtable0.access_key, "-->"), LPAD(PMEtable0.id,3,"0"))',
		'escape' => false
		);

$template_keys = ezin_admin_get_template_keys($ezin_sys['tmpl']['articles']);
if (count($template_keys) > 0) {
	$ezin_opts['fdd']['template_key'] = array(
			'name'=>Platon::htmlspecialchars2('Template key'),
			'select'=>'T',
			'sort'=>true,
			'options'=>'ACPDV',
			'values2'=> array(''=>' - default template - '),
			'values' => $template_keys
			);
}

$ezin_opts['fdd']['access_key'] = array(
		'name'=>Platon::htmlspecialchars2('Access key'),
		'name|LF'=>'Key',
		'select'=>'T',
		'sort'=>true,
		'options'=>'ACPDV'
		);

$ezin_opts['fdd']['accesses_count'] = array(
		'name'=>Platon::htmlspecialchars2('Accesses count'),
		'options'=>'VDACP'.'HR',
		'default'=>'0'
		);

$ezin_opts['fdd']['sessions_count'] = array(
		'name'=>Platon::htmlspecialchars2('Sessions count'),
		'options'=>'VDACP'.'HR',
		'default'=>'0'
		);

$ezin_opts['fdd']['name'] = array(
		'name'=>'Name',
		'select'=>'T',
		'maxlen'=>60,
		'sort'=>true,
		'required'=>true
		);

$ezin_opts['fdd']['email'] = array(
		'name'=>'E-mail',
		'select'=>'T',
		'maxlen'=>60,
		'sort'=>true,
		'URLprefix'=>'mailto:',
		'URLtarget'=>'_blank'
		);

$ezin_opts['fdd']['homepage'] = array(
		'name'=>'Homepage',
		'select'=>'T',
		'maxlen'=>60,
		'sort'=>true,
		'URLprefix'=>array('http://', 'https://', 'ftp://'),
		'URLtarget'=>'_blank'
		);

$ezin_opts['fdd']['description'] = array(
		'name'=>'Description',
		'select'=>'T',
		'textarea'=>array(
			'rows'=>5,
			'cols'=>65,
			),
		'sort'=>true,
		'options'=>'ACPV'
		);

$ezin_opts['fdd']['description_wordcount'] = array(
		'name'=>Platon::htmlspecialchars2('Description word count'),
		'select'=>'T',
		'options'=>'HCAP'
		);

$ezin_opts['fdd']['description_flags'] = array(
		'name'=>Platon::htmlspecialchars2('Description flags'),
		'select'=>'T',
		'options'=>'HCAP'
		);

// Execution code

if (! ezin_admin_check_list_privileges($ezin_opts['options'])) {
	require 'inc-html/permdenied.html';
} else {
	/* if (! ezin_admin_check_privileges($ezin_opts['options'],
	   $rec == $ezin_USER['author_id'])) {
	   require 'inc-html/permdenied.html';
	   } */

	require_once 'phpMyEdit/phpMyEdit.class.php';
	new phpMyEdit($ezin_opts);
}

?>
